@@ -5,16 +5,27 @@
 #pragma once
 
 #include <QObject>
+#include <QQuickItem>
 #include <QQuickWebEngineProfile>
 #include <QWebEngineUrlRequestInterceptor>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+class QQuickWebEngineDownloadItem;
+using DownloadItem = QQuickWebEngineDownloadItem;
+#else
+class QQuickWebEngineDownloadRequest;
+using DownloadItem = QQuickWebEngineDownloadRequest;
+#endif
+
 class QWebEngineNotification;
+class QQuickItem;
+class QWebEngineUrlRequestInterceptor;
 
 class AngelfishWebProfile : public QQuickWebEngineProfile
 {
     Q_OBJECT
 
-    Q_PROPERTY(QObject *questionLoader MEMBER m_questionLoader NOTIFY questionLoaderChanged)
+    Q_PROPERTY(QQuickItem *questionLoader MEMBER m_questionLoader NOTIFY questionLoaderChanged)
     Q_PROPERTY(QWebEngineUrlRequestInterceptor *urlInterceptor WRITE setUrlInterceptor READ urlInterceptor NOTIFY urlInterceptorChanged)
 
 public:
@@ -27,11 +38,11 @@ public:
     void setUrlInterceptor(QWebEngineUrlRequestInterceptor *urlRequestInterceptor);
 
 private:
-    void handleDownload(QQuickWebEngineDownloadItem *downloadItem);
-    void handleDownloadFinished(QQuickWebEngineDownloadItem *downloadItem);
+    void handleDownload(DownloadItem *downloadItem);
+    void handleDownloadFinished(DownloadItem *downloadItem);
     void showNotification(QWebEngineNotification *webNotification);
 
-    QObject *m_questionLoader;
+    QQuickItem *m_questionLoader;
 
     // A valid property needs a read function, and there is no getter in QQuickWebEngineProfile
     // so store a pointer ourselves
