@@ -38,6 +38,8 @@ auto toQtType(T input) {
             return QString::fromStdString(std::string(c));
         });
         return qStringVec;
+    } else if constexpr (std::is_same_v<T, rust::String>) {
+        return QString::fromStdString(std::string(input));
     }
 }
 #endif
@@ -135,7 +137,7 @@ std::vector<QString> AdblockUrlInterceptor::getCosmeticFilters(const QUrl &url,
                                                                const std::vector<QString> &ids) const
 {
     if (!m_adblock.has_value()) {
-        return std::vector<QString>();
+        return {};
     }
 
     const auto rustClasses = toRustType(classes);
@@ -144,6 +146,16 @@ std::vector<QString> AdblockUrlInterceptor::getCosmeticFilters(const QUrl &url,
                                                      {rustClasses.data(), rustClasses.size()},
                                                      {rustIds.data(), rustIds.size()}));
 }
+
+QString AdblockUrlInterceptor::getInjectedScript(const QUrl &url) const
+{
+    if (!m_adblock) {
+        return {};
+    }
+
+    auto u = (*m_adblock)->getInjectedScript(url.toString().toStdString());
+    return toQtType(u);
+}
 #endif
 
 inline auto resourceTypeToString(const QWebEngineUrlRequestInfo::ResourceType type)
@@ -200,10 +212,13 @@ void AdblockUrlInterceptor::interceptRequest(QWebEngineUrlRequestInfo &info)
     const AdblockResult result = (*m_adblock)->shouldBlock(url, firstPartyUrl, resourceTypeToString(info.resourceType()));
 
     const auto &redirect = result.redirect;
+    const auto &rewrittenUrl = result.rewrittenUrl;
     if (!redirect.empty()) {
         info.redirect(QUrl(QString::fromStdString(std::string(redirect))));
-    } else {
+    } else if (result.matched) {
         info.block(result.matched);
+    } else if (!rewrittenUrl.empty()) {
+        info.redirect(QUrl(QString::fromStdString(std::string(rewrittenUrl))));
     }
 #else
     Q_UNUSED(info);
